@@ -4,9 +4,9 @@
     'name': 'Analytic Purchase',
     'name_de_DE': 'Kostenstellen Einkauf',
     'name_es_CO': 'Compra Analítica',
-    'name_es_ES': 'Compra Analítica',
+    'name_es_ES': 'Compra analítica',
     'name_fr_FR': 'Achat analytique',
-    'version': '1.2.0',
+    'version': '1.4.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -16,8 +16,7 @@
 ''',
     'description_es_CO': '''Adiciona contabilidad analítica a las líneas de compra.
 ''',
-    'description_es_ES': '''Adiciona contabilidad analítica a las líneas de compra.
-''',
+    'description_es_ES': 'Añade contabilidad analítica a las líneas de compra.',
     'description_fr_FR': 'Ajoute la comptabilité analytique sur les lignes d\'achat.',
     'depends': [
         'purchase',
